@@ -105,7 +105,7 @@ elseif ($App->getSession('LANG')) {
     $App->setLang($App->getSession('LANG'));
 }
 else {
-    if ($App->getConfig('FORCE_DEFAULT_LANGUAGE') == 'true') {
+    if ($App->getConfig('FORCE_DEFAULT_LANGUAGE','false') == 'true') {
         $App->setLang($App->getConfig('DEFAULT_LANGUAGE','de'));
     }
     else {
