@@ -405,7 +405,7 @@ class Application extends ApplicationConfig
      * @param string $default (optional)
      * @return arrray $params
      */
-    function getConfigList ($name,$default=false)
+    function getConfigList ($name,$default=array())
     {
         if (isset($this->config[$name])) {
             return  preg_split('/,(\s+)?/',$this->config[$name]);
@@ -414,7 +414,7 @@ class Application extends ApplicationConfig
             return $default;
         }
         else {
-            return false;
+            return $default;
         }
     }
 
