@@ -70,7 +70,7 @@ class ApplicationConfig
     function ApplicationConfig ($configdir)
     {
         $this->configdir = $configdir;
-        $this->parameters = []; 
+        $this->parameters = array(); 
     }
 
 
