@@ -31,8 +31,8 @@
  * Suite 330, Boston, MA  02111-1307  USA
  */
 
-$sendmail_cmd = $App->getConfig('SENDMAIL_CMD');
-$mail_from = $App->getConfig('MAIL_FROM');
+$sendmail_cmd = $App->getConfig('SENDMAIL_CMD','/usr/sbin/sendmail');
+$mail_from = $App->getConfig('MAIL_FROM','benno');
 
 $sessionMailId = $App->getParam('sessionMailId');
 $mailTo = $App->getParam('mailTo');
