@@ -44,6 +44,10 @@ catch (Exception $e) {
     $App->setMsg($e->getMessage());
 }
 
+if($exitview = $App->getParam('exitview')) {
+    $App->setSession('exitview',$exitview);
+}
+
 $show_greeting = true;
 // enable template code for asyncronous dummy request
 $App->assign('CACHE_WARMING_REQUEST','true');
