@@ -36,7 +36,7 @@ require_once 'model/DateConvert.php';
 require_once 'model/Filter.php';
 require_once 'model/AppState.php';
 
-$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/lib/benno-web/benno_dbauth');
+$authscript  = $App->getConfig('EXTERNAL_AUTH','/usr/sbin/benno_auth.d');
 
 $login = $App->getParam('login');
 
@@ -81,6 +81,7 @@ catch (Exception $e) {
 
 // LOGIN SUCCESSFUL
 $App->log('Authentication of '.$USER->id. ' successful',1);
+$App->setSession('DISABLED',$App->getConfigList('INFO_DISABLED',array()));
 
 // initialize backend
 $FilterList = Filter::FetchList($USER);
@@ -100,8 +101,18 @@ $App->setSession('ExtQuery',$ExtQuery);
 
 $App->setSession('QueryList',StoredQuery::FetchList($USER->id));
 
-// list of assigened archives
+// list of assigned archives
 $archive_list = $USER->getArchives();
+foreach ($archive_list as $archive) { // disable index counter if subarchives available
+    list($cidstring,$scid) = preg_split('/\/+(?=[^\/]+$)/',$archive);
+    if ($scid) {
+        // disable indexed mails counter always
+        $DISABLED = $App->getSession('DISABLED');
+        array_push($DISABLED,'INDEXCOUNT');
+        $App->setSession('DISABLED',$DISABLED);
+    }
+}
+
 
 // restore state of last session
 try {
