@@ -32,17 +32,11 @@
  */
 
 $configfile = "/etc/benno-web/benno.conf";
-$UNICODE=TRUE;
+$header_template = 'header.tpl';
+$footer_template = 'footer.tpl';
+$default_action  = 'default';
 
-// class Authorization
-// {
-// 	function check ()
-// 	{
-// 		echo "check function.\n";
-// //		return FALSE;
-// 		return TRUE;
-// 	}
-// }
+$UNICODE=TRUE;
 
 require 'SPAF2.php';
 ?>
