@@ -118,7 +118,7 @@ class AppState extends Persistence
 
 
     /**
-     * setValue for id
+     * saveValue for id
      *
      * store value in db backend
      *
@@ -126,7 +126,7 @@ class AppState extends Persistence
      * @param string $param
      * @param string $value
      */
-    function setValue($param,$value)
+    function saveValue($param,$value)
     {
         $this->id = $param;
         $this->value = $value;
