@@ -254,17 +254,8 @@ class EMail
 
             $content = $body[$contentType];
             if (!$content) {
-                if ($body['text/plain']) {
-                    $App->log('[model/EMail] Only text/plain body found.');
-                    throw new Exception('CONTENT_PLAIN');
-                }
-                if ($body['text/html']) {
-                    $App->log('[model/EMail] Only text/html body found.');
-                    throw new Exception('CONTENT_HTML');
-                }
-
-                $App->log('[model/EMail] Unknown body content in '.$this->bennoId);
-                throw new Exception('CONTENT_UNKNOWN');
+                $App->log('[model/EMail] Only text/plain body found.',1,'EMail');
+                throw new Exception('NO_CONTENT');
             }
         }                               // text/plain
         return $content;
