@@ -43,7 +43,8 @@ class Query
     var $archive;           // archive for search
     var $text;              // content or search term
     var $sender;
-    var $recipient; var $subject;
+    var $recipient;
+    var $subject;
     var $headerName;        // will only be set on extended search
     var $headerValue;       // will only be set on extended search
     var $isAttachment;
@@ -404,11 +405,6 @@ class Query
     }
 
 
-
-
-
-
-
     /**
      * format querystring
     */
@@ -423,15 +419,23 @@ class Query
             $fieldlist = array($field);
         }
         $tokenlist = $this->_tokenize_query($qstring);
+
         $query_string = '';
         foreach ($fieldlist as $field) {
             $field_string = $this->_format_fieldstring($field,$tokenlist);
             $query_string .= '('.$field_string.')';
         }
 
+        if ($App->getConfig('SUPPRESS_SINGLE_WILDCARD')) {
+            if (preg_grep('/^\*$/',$tokenlist)) {
+                $App->log('[Query] Single wildcard in in query:'.$query_string,1);
+                throw new Exception('LEADING_WILDCARD');
+            }
+        }
+
         if ($App->getConfig('SUPPRESS_LEADING_WILDCARD')) {
             if (preg_match('/:[\*\?]/',$query_string)) {
-                $App->log('[Query] Remove leading wildcards from query.',2);
+                $App->log('[Query] Remove leading wildcards from query.',1);
                 throw new Exception('LEADING_WILDCARD');
             }
         }
