@@ -336,10 +336,21 @@ $.dpText = {
 
 // Container Switch
 $('#select_container').change(function(){
+var currentArchive=$('archive').val();
 $.ajax({
     'url': '',
     'data':{ 'CA': 'a_switchContainer',
              'container': $('#select_container').val(),
            },
+    'success':  function(retval){  // show container switch
+                    if ($('#archive').val() == $('#select_container option:selected').text()) {
+                        $('#overview_content').css('filter','opacity(1)'); 
+                        $('.scroll-panel2').css('filter','opacity(1)'); 
+                    }
+                    else {
+                        $('#overview_content').css('filter','opacity(0.4)'); 
+                        $('.scroll-panel2').css('filter','opacity(0.4)'); 
+                    }
+                }
 });
 });
