@@ -40,7 +40,12 @@ $App->setSession('EMail',$EMail);
 $App->setSession('search_limit',$search_limit);
 $App->setSession('timeslice',$timeslice);
 $App->setSession('sortOrder',$sortOrder);
+if ($QueryResult->overall > 0) {
+    $mailCount = $QueryResult->overall;
+    $App->setSession('mailCount',$mailCount);
+}
 
+$App->assign('mailCount',$mailCount);
 $App->assign('QueryList',$QueryList);
 $App->assign('QueryResult',$QueryResult);
 $App->assign('SimpleQuery',$SimpleQuery);
